# scans2any

IP-Addresses | Hostnames | Ports | Services | Banners | OS
--- | --- | --- | --- | --- | ---
192.168.56.10 |  | 53/tcp 53/udp 80/tcp 88/tcp 123/udp 135/tcp 137/udp 139/tcp 389/tcp 445/tcp 464/tcp 593/tcp 636/tcp 3268/tcp 3269/tcp 3389/tcp 5355/udp 5985/tcp 5986/tcp 9389/tcp 47001/tcp 49664/tcp 49665/tcp 49666/tcp 49667/tcp 49669/tcp 49670/tcp 49672/tcp 49675/tcp 49685/tcp 49785/tcp 49863/tcp 49966/tcp | dns dns www kerberos? ntp epmap netbios-ns smb ldap cifs kpasswd? http-rpc-epmap ldap ldap ldap msrdp llmnr www www www dce-rpc dce-rpc dce-rpc dce-rpc ncacn_http dce-rpc dce-rpc dce-rpc dce-rpc dce-rpc dce-rpc dce-rpc | Microsoft-IIS/10.0 Microsoft-HTTPAPI/2.0 Microsoft-HTTPAPI/2.0 Microsoft-HTTPAPI/2.0 | windows
192.168.56.11 |  | 53/tcp 53/udp 88/tcp 123/udp 135/tcp 137/udp 139/tcp 389/tcp 445/tcp 464/tcp 593/tcp 636/tcp 3268/tcp 3269/tcp 3389/tcp 5355/udp 5985/tcp 5986/tcp 9389/tcp 47001/tcp 49664/tcp 49665/tcp 49666/tcp 49667/tcp 49669/tcp 49670/tcp 49673/tcp 49676/tcp 49722/tcp 65363/tcp 65464/tcp | dns dns kerberos? ntp epmap netbios-ns smb ldap cifs kpasswd? http-rpc-epmap ldap ldap ldap msrdp llmnr www www www dce-rpc dce-rpc dce-rpc dce-rpc dce-rpc ncacn_http dce-rpc dce-rpc dce-rpc dce-rpc dce-rpc | Microsoft-HTTPAPI/2.0 Microsoft-HTTPAPI/2.0 Microsoft-HTTPAPI/2.0 | windows
192.168.56.22 |  | 80/tcp 135/tcp 137/udp 139/tcp 445/tcp 1433/tcp 3389/tcp 5355/udp 5985/tcp 5986/tcp 47001/tcp 49664/tcp 49665/tcp 49666/tcp 49667/tcp 49668/tcp 49669/tcp 49682/tcp 49734/tcp 49813/tcp | www epmap netbios-ns smb cifs mssql msrdp llmnr www www www dce-rpc dce-rpc dce-rpc dce-rpc dce-rpc dce-rpc dce-rpc dce-rpc sybase | Microsoft-IIS/10.0 Microsoft-HTTPAPI/2.0 Microsoft-HTTPAPI/2.0 Microsoft-HTTPAPI/2.0 | windows